==> PerformanceAnalytics_0.9.7.1.tar.gz: PerformanceAnalytics/R/DownsideDeviation.R <==
`DownsideDeviation` <-
function (Ra, MAR = 0, method=c("subset","full"))
{ # @author Peter Carl

    # DESCRIPTION:
    # Downside deviation, similar to semi deviation, eliminates positive returns
    # when calculating risk.  To calculate it, we take the returns that are less
    # than the target (or Minimum Acceptable Returns (MAR)) returns and take the
    # differences of those to the target.  We sum the squares and divide by the
    # total number of returns to get a below-target semi-variance.

    # This is also useful for calculating semi-deviation by setting
    # MAR = mean(x)

    method = method[1] # grab the first value if this is still a vector, to avoid varnings
    # FUNCTION:

    Ra = checkData(Ra, method="vector")
    if(!is.null(dim(MAR)))
        MAR = mean(checkData(MAR, method = "vector"))
    # we have to assume that Ra and a vector of Rf passed in for MAR both cover the same time period
    # subset won't work with zoo objects
    r = subset(Ra,Ra < MAR)

    switch(method,
        full   = {len = length(Ra)},
        subset = {len = length(r)} #previously length(R)
    ) # end switch
    return(sqrt(sum((r - MAR)^2)/len))
}

###############################################################################
# R (http://r-project.org/) Econometrics for Performance and Risk Analysis
#
# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
#
# This library is distributed under the terms of the GNU Public License (GPL)
# for full details see the file COPYING
#
# $Id: DownsideDeviation.R,v 1.10 2008-09-30 21:17:24 brian Exp $
#
###############################################################################
# $Log: DownsideDeviation.R,v $
# Revision 1.10  2008-09-30 21:17:24  brian
# - both DownsideDeviation and UpsidePotentialRatio now support "method argument to use full or subset of series
# - use subset as default method
# - updated documentation to reflect change
#
# Revision 1.9  2008-06-02 16:05:19  brian
# - update copyright to 2004-2008
#
# Revision 1.8  2007/10/11 03:22:04  peter
# - fixed "subset" to use r instead of R
#
# Revision 1.7  2007/08/16 14:09:33  peter
# - added checkData for MAR in case it is a vector of Rf
#
# Revision 1.6  2007/08/03 14:58:26  brian
# - add use of length of full series or subset below MAR
# - set proper values for SemiVariance(subset), and SemiDeviation(full)
# - allow DownsideDeviation user to choose, default method="full"
#
# Revision 1.5  2007/06/21 21:36:08  brian
# - fixed to use length of entire series, per Platinga, van der Meer, Sortino 2001
#
# Revision 1.4  2007/06/21 21:24:39  brian
# - update to use length rather than length-1 after reviewing several original Sortino papers
#
# Revision 1.3  2007/03/14 00:54:06  brian
# - updates to parameters for standardization
#
# Revision 1.2  2007/02/07 13:24:49  brian
# - fix pervasive comment typo
#
# Revision 1.1  2007/02/02 19:06:15  brian
# - Initial Revision of packaged files to version control
# Bug 890
#
###############################################################################

==> PerformanceAnalytics_1.0.0.tar.gz: PerformanceAnalytics/R/DownsideDeviation.R <==
`DownsideDeviation` <-
function (R, MAR = 0, method=c("subset","full"))
{ # @author Peter Carl

    # DESCRIPTION:
    # Downside deviation, similar to semi deviation, eliminates positive returns
    # when calculating risk.  To calculate it, we take the returns that are less
    # than the target (or Minimum Acceptable Returns (MAR)) returns and take the
    # differences of those to the target.  We sum the squares and divide by the
    # total number of returns to get a below-target semi-variance.

    # This is also useful for calculating semi-deviation by setting
    # MAR = mean(x)

    method = method[1] 

    if (is.vector(R)) {
        R = na.omit(R)

        if(!is.null(dim(MAR)))
            MAR = mean(checkData(MAR, method = "vector"))
        # we have to assume that Ra and a vector of Rf passed in for MAR both cover the same time period

        r = subset(R, R < MAR)

        switch(method,
            full   = {len = length(R)},
            subset = {len = length(r)} #previously length(R)
        ) # end switch
        result = sqrt(sum((r - MAR)^2)/len)
        return(result)
    }
    else {
        R = checkData(R, method = "matrix")
        result = apply(R, MARGIN = 2, DownsideDeviation, MAR = MAR, method = method)
        dim(result) = c(1,NCOL(R))
        colnames(result) = colnames(R)
        rownames(result) = paste("Downside Deviation (MAR = ", round(MAR*100,1),"%)", sep="")
        return(result)
    }
}

###############################################################################
# R (http://r-project.org/) Econometrics for Performance and Risk Analysis
#
# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
#
# This library is distributed under the terms of the GNU Public License (GPL)
# for full details see the file COPYING
#
# $Id: DownsideDeviation.R,v 1.14 2009-10-10 12:40:08 brian Exp $
#
###############################################################################
# $Log: DownsideDeviation.R,v $
# Revision 1.14  2009-10-10 12:40:08  brian
# - update copyright to 2004-2009
#
# Revision 1.13  2009-10-06 15:14:44  peter
# - fixed rownames
# - fixed scale = 12 replacement errors
#
# Revision 1.12  2009-10-06 02:59:49  peter
# - added label to results
#
# Revision 1.11  2009-09-24 03:35:59  peter
# - added multi-column support
#
# Revision 1.10  2008-09-30 21:17:24  brian
# - both DownsideDeviation and UpsidePotentialRatio now support "method argument to use full or subset of series
# - use subset as default method
# - updated documentation to reflect change
#
# Revision 1.9  2008-06-02 16:05:19  brian
# - update copyright to 2004-2008
#
# Revision 1.8  2007/10/11 03:22:04  peter
# - fixed "subset" to use r instead of R
#
# Revision 1.7  2007/08/16 14:09:33  peter
# - added checkData for MAR in case it is a vector of Rf
#
# Revision 1.6  2007/08/03 14:58:26  brian
# - add use of length of full series or subset below MAR
# - set proper values for SemiVariance(subset), and SemiDeviation(full)
# - allow DownsideDeviation user to choose, default method="full"
#
# Revision 1.5  2007/06/21 21:36:08  brian
# - fixed to use length of entire series, per Platinga, van der Meer, Sortino 2001
#
# Revision 1.4  2007/06/21 21:24:39  brian
# - update to use length rather than length-1 after reviewing several original Sortino papers
#
# Revision 1.3  2007/03/14 00:54:06  brian
# - updates to parameters for standardization
#
# Revision 1.2  2007/02/07 13:24:49  brian
# - fix pervasive comment typo
#
# Revision 1.1  2007/02/02 19:06:15  brian
# - Initial Revision of packaged files to version control
# Bug 890
#
###############################################################################
